pub struct CommittedCandidateReceipt<H = H256> {
pub descriptor: CandidateDescriptorV2<H>,
pub commitments: CandidateCommitments,
}Expand description
A candidate-receipt with commitments directly included.
Fields
descriptor: CandidateDescriptorV2<H>The descriptor of the candidate.
commitments: CandidateCommitmentsThe commitments of the candidate receipt.
Implementations
Sourceimpl<H> CommittedCandidateReceiptV2<H>where
H: Clone,
impl<H> CommittedCandidateReceiptV2<H>where
H: Clone,
Sourcepub fn to_plain(&self) -> CandidateReceiptV2<H>
pub fn to_plain(&self) -> CandidateReceiptV2<H>
Transforms this into a plain CandidateReceipt.
Sourcepub fn hash(&self) -> CandidateHashwhere
H: Encode,
pub fn hash(&self) -> CandidateHashwhere
H: Encode,
Computes the hash of the committed candidate receipt.
This computes the canonical hash, not the hash of the directly encoded data.
Thus this is a shortcut for candidate.to_plain().hash().
Sourcepub fn corresponds_to(&self, receipt: &CandidateReceiptV2<H>) -> boolwhere
H: PartialEq,
pub fn corresponds_to(&self, receipt: &CandidateReceiptV2<H>) -> boolwhere
H: PartialEq,
Does this committed candidate receipt corresponds to the given CandidateReceiptV2?
Sourceimpl<H> CommittedCandidateReceiptV2<H>
impl<H> CommittedCandidateReceiptV2<H>
Sourcepub fn parse_ump_signals(
&self,
cores_per_para: &BTreeMap<Id, BTreeMap<u8, BTreeSet<CoreIndex>>>,
) -> Result<CandidateUMPSignals, CommittedCandidateReceiptError>
pub fn parse_ump_signals( &self, cores_per_para: &BTreeMap<Id, BTreeMap<u8, BTreeSet<CoreIndex>>>, ) -> Result<CandidateUMPSignals, CommittedCandidateReceiptError>
Performs checks on the UMP signals and returns them.
Also checks if descriptor core index is equal to the committed core index.
Params:
cores_per_parais a claim queue snapshot at the candidate’s relay parent, stored as a mapping betweenParaIdand the cores assigned per depth.
NOTE: This must only be called in the runtime and backing - never in approval voting nor disputes! At least not as long as nodes exist which don’t understand v3 candidate descriptors. Not checking there is fine, because it is checked by the runtime - if it can be disputed, it has been checked already!